@@ -33,7 +33,7 @@ var searchData=
   ['kdingbat_30',['kDingbat',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29acfdf9bb31949a76f6c6f21b44a2ac76d',1,'com::sun::star::i18n']]],
   ['keep_31',['KEEP',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1NameClash.html#a28e859852ecabe5a1de9e0d2d9a69df3',1,'com::sun::star::ucb::NameClash']]],
   ['keepformats_32',['KeepFormats',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ac34b74170aee53aa1f3898b38f5ac393',1,'com::sun::star::sheet::DatabaseRange']]],
-  ['keeptogether_33',['KeepTogether',['../servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::text::TextTable::KeepTogether()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::report::XSection::KeepTogether()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html#a8c23ee90f1673324ebe9be853d698d0b',1,'com::sun::star::report::XGroup::KeepTogether()']]],
+  ['keeptogether_33',['KeepTogether',['../interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::report::XSection::KeepTogether()'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::text::TextTable::KeepTogether()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html#a8c23ee90f1673324ebe9be853d698d0b',1,'com::sun::star::report::XGroup::KeepTogether()']]],
   ['keeptogether_2eidl_34',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
   ['kenclosedalphanumeric_35',['kEnclosedAlphanumeric',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a9cc4022bbb05d394f6c58db7596464d0',1,'com::sun::star::i18n']]],
   ['kenclosedcjklettermonth_36',['kEnclosedCJKLetterMonth',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac91cc150a9f0e68c0a2668eda40af086',1,'com::sun::star::i18n']]],
